@@ -1,6 +1,6 @@
 /* context2.h -- manages the libSieve opaque context and callbacks.
  * Aaron Stone
- * $Id: context2.h 143 2008-11-13 03:58:25Z sodabrew $
+ * $Id$
  */
 /* * * *
  * Copyright 2005 by Aaron Stone
@@ -13,8 +13,8 @@
 #define CONTEXT2_H
 
 #include "tree.h"		/* for commandlist_t */
+#include "src/sv_include/sieve2.h"
 #include "message2.h"
-#include "sieve2.h"
 
 struct callbacks2 {
     sieve2_callback_func redirect;
@@ -101,7 +101,7 @@ struct cur_call {
         } type;
         union {
             int i;
-            char *s;
+            char const *s;
             char **sl;
         } value;
     } values [MAX_VALUES];
@@ -111,7 +111,12 @@ struct sieve2_context {
     sieve2_message_t *message;
     stringlist_t *slflags;
     struct mlbuf *strbuf;
-
+    void *addr_scan;
+    struct address *addr_addr;
+    void *sieve_scan;
+    commandlist_t *sieve_ret;
+    void *header_scan;
+    struct header_list *header_hl;
     int parse_errors;
     int exec_errors;
 
