@@ -1,6 +1,6 @@
 /* message2.h
  * Aaron Stone
- * $Id: message2.h 143 2008-11-13 03:58:25Z sodabrew $
+ * $Id$
  */
 /* * * *
  * Copyright 2005 by Aaron Stone
@@ -40,7 +40,7 @@ typedef struct message {
     header_list_t *list;
 } sieve2_message_t;
 
-int libsieve_message2_parseheader(sieve2_message_t *m);
+int libsieve_message2_parseheader(struct sieve2_context *context);
 int libsieve_message2_alloc(sieve2_message_t **m);
 int libsieve_message2_free(sieve2_message_t **m);
 
