@@ -1,6 +1,6 @@
 /* test.c -- test and example for sieve version 2 api
  * Aaron Stone
- * $Id: example.c 143 2008-11-13 03:58:25Z sodabrew $
+ * $Id$
  *
  * usage: "test message script"
  */
@@ -56,7 +56,7 @@ struct freelist {
 };
 
 struct my_context {
-	int m_size;
+	const int m_size;
 	char *m_buf;
 	char *s_buf;
 	char *scriptfile;
